what.models.detection API documentation

# what.models.detection

This module implements several object detection models and provides some utility functions.

## what.models.detection.yolo

## what.models.detection.ssd

## what.models.detection.frcnn

View Source

     1r'''
     2This module implements several object detection models and provides some utility functions.
     3
     4## what.models.detection.yolo
     5## what.models.detection.ssd
     6## what.models.detection.frcnn
     7'''
     8
     9from what.models.detection import yolo
    10from what.models.detection import ssd
    11from what.models.detection import frcnn